/**
 *    FolderSettings.java
 *    Copyright (C) 2010 New Zealand Digital Library, http://expeditee.org
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.expeditee.settings.folders;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.expeditee.gui.AttributeValuePair;
import org.expeditee.gui.FrameIO;
import org.expeditee.gui.FrameUtils;
import org.expeditee.items.Text;
import org.expeditee.setting.DirectoryListSetting;
import org.expeditee.setting.ListSetting;
import org.expeditee.setting.Setting;

public class FolderSettings {

	public static final DirectoryListSetting FrameDirs = new DirectoryListSetting("Directories to look in for frames", "FrameDirs");
	
	public static final Setting FramesetDir = new Setting("Adds a directory to look in for frames", "FramesetDir") {
		@Override
		public boolean setSetting(Text text) {
			if(text.getText().indexOf(':') == -1) {
				return false;
    		}
    		AttributeValuePair avp = new AttributeValuePair(text.getText());
    		if(avp.getValue().trim().length() != 0) {
    			String dir = FrameUtils.getDir(avp.getValue());
    			if (dir != null) {
    				FolderSettings.FrameDirs.get().add(dir);
    				return true;
    			}
    		}
    		return false;
		}
		
		@Override
		public Text generateRepresentation(String label, String frameset) {
			Text t = new Text(label);
			return t;
		}
	};

	public static DirectoryListSetting ImageDirs = new DirectoryListSetting("Directories to look in for images", "ImageDirs");
			
	public static final Setting ImageDir = new Setting("Adds a directory to look in for images", "ImageDir") {
		@Override
		public boolean setSetting(Text text) {
    		if(text.getText().indexOf(':') == -1) {
    			return false;
    		}
    		AttributeValuePair avp = new AttributeValuePair(text.getText());
    		if(avp.getValue().trim().length() != 0) {
    			String dir = FrameUtils.getDir(avp.getValue());
    			if(dir != null) {
    				FolderSettings.ImageDirs.get().add(0, dir);
    				return true;
    			}
    		}
    		return false;
		}
		
		@Override
		public Text generateRepresentation(String label, String frameset) {
			Text t = new Text(label);
			return t;
		}
	};
	
	
	public static DirectoryListSetting AudioDirs = new DirectoryListSetting("Directories to look in for audio", "AudioDirs");
	
	public static final Setting AudioDir = new Setting("Adds a directory to look in for audio", "AudioDir") {
		@Override
		public boolean setSetting(Text text) {
    		if(text.getText().indexOf(':') == -1) {
    			return false;
    		}
    		AttributeValuePair avp = new AttributeValuePair(text.getText());
    		if(avp.getValue().trim().length() != 0) {
    			String dir = FrameUtils.getDir(avp.getValue());
    			if(dir != null) {
    				FolderSettings.AudioDirs.get().add(0, dir);
    				return true;
    			}
    		}
    		return false;
		}
		
		@Override
		public Text generateRepresentation(String label, String frameset) {
			Text t = new Text(label);
			return t;
		}
	};
	
	
	public static final Setting LogDir = new Setting("Set the directory to save logs", "LogDir") {
		@Override
		public boolean setSetting(Text text) {
			if(text.getText().indexOf(':') == -1) {
    			return false;
    		}
    		AttributeValuePair avp = new AttributeValuePair(text.getText());
    		if(avp.getValue().trim().length() != 0) {
    			FrameIO.LOGS_DIR = FrameUtils.getDir(avp.getValue());
    		}
    		return true;
		}
		
		@Override
		public Text generateRepresentation(String label, String frameset) {
			Text t = new Text(label);
			return t;
		}
	};
}
